@@ -273,7 +273,7 @@ class Screen:
             prompt: str,
             opt_strs: Tuple[str, ...],
     ) -> Union[str, PromptResult]:
-        opts = [opt[0] for opt in opt_strs]
+        opts = {opt[0] for opt in opt_strs}
         while True:
             x = 0
             prompt_line = self.margin.lines - 1
@@ -310,8 +310,8 @@ class Screen:
                 self.resize()
             elif key.keyname == b'^C':
                 return self.status.cancelled()
-            elif isinstance(key.wch, str) and key.wch in opts:
-                return key.wch
+            elif isinstance(key.wch, str) and key.wch.lower() in opts:
+                return key.wch.lower()
 
     def prompt(
             self,
@@ -508,8 +508,14 @@ class Screen:
             self.status.update('(file changed on disk, not implemented)')
             return PromptResult.CANCELLED
 
-        with open(self.file.filename, 'w', encoding='UTF-8', newline='') as f:
-            f.write(contents)
+        try:
+            with open(
+                self.file.filename, 'w', encoding='UTF-8', newline='',
+            ) as f:
+                f.write(contents)
+        except OSError as e:
+            self.status.update(f'cannot save file: {e}')
+            return PromptResult.CANCELLED
 
         self.file.modified = False
         self.file.sha256 = sha256_to_save
